@@ -4,11 +4,11 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 1;
 
-# ABSTRACT: BETA Perl API for MaxMind's minFraud Score and Insights web services
+# ABSTRACT: BETA API for MaxMind's minFraud Score, Insights, and Factors services
 
 __END__
 
@@ -16,11 +16,11 @@ __END__
 
 =head1 NAME
 
-WebService::MinFraud - BETA Perl API for MaxMind's minFraud Score and Insights web services
+WebService::MinFraud - BETA API for MaxMind's minFraud Score, Insights, and Factors services
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -44,8 +44,8 @@ version 0.002000
 
   my $request = { device => { ip_address => '24.24.24.24' } };
 
-  # Use the 'score' or 'insights' client methods, depending on the minFraud
-  # web service you are using.
+  # Use the 'score', 'insights', or 'factors' client methods, depending on
+  # the minFraud web service you are using.
 
   my $score = $client->score( $request );
   say $score->risk_score;
@@ -53,10 +53,13 @@ version 0.002000
   my $insights = $client->insights( $request );
   say $insights->shipping_address->is_high_risk;
 
+  my $factors = $client->factors( $request );
+  say $factors->subscores->ip_tenure;
+
 =head1 DESCRIPTION
 
 This distribution provides a BETA API for the
-L<MaxMind minFraud Score and Insights web services|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
+L<MaxMind minFraud Score, Insights, and Factors web services|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
 
 See L<WebService::MinFraud::Client> for details on using the web service client
 API.
@@ -64,7 +67,7 @@ API.
 =head1 INSTALLATION
 
 The minFraud Perl API and its dependencies can be installed with
-L<cpanm|https://metacpan.org/pod/App::cpanminus>.  C<< cpanm >> itself has no
+L<cpanm|https://metacpan.org/pod/App::cpanminus>. C<< cpanm >> itself has no
 dependencies.
 
   cpanm WebService::MinFraud
@@ -78,7 +81,7 @@ The minFraud Perl API uses L<Semantic Versioning|http://semver.org/>.
 The minimum required Perl version for the minFraud Perl API is 5.10.0.
 
 The data returned from the minFraud web services includes Unicode characters
-in several locales. This may expose bugs in earlier versions of Perl.  If
+in several locales. This may expose bugs in earlier versions of Perl. If
 Unicode is important to your work, we recommend that you use the most recent
 version of Perl available.
 
@@ -116,7 +119,7 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
