@@ -3,7 +3,7 @@ package WebService::MinFraud::Client;
 use 5.010;
 use Moo 1.004005;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 use HTTP::Headers ();
 use HTTP::Request ();
@@ -16,8 +16,8 @@ use Types::Standard qw( InstanceOf );
 use URI ();
 use WebService::MinFraud::Error::Generic;
 use WebService::MinFraud::Error::HTTP;
-use WebService::MinFraud::Error::IPAddressNotFound;
 use WebService::MinFraud::Error::WebService;
+use WebService::MinFraud::Model::Factors;
 use WebService::MinFraud::Model::Insights;
 use WebService::MinFraud::Model::Score;
 use WebService::MinFraud::Types
@@ -101,6 +101,15 @@ sub BUILD {
     $ua->agent($agent);
 }
 
+sub factors {
+    my $self = shift;
+
+    return $self->_response_for(
+        'factors',
+        'WebService::MinFraud::Model::Factors', @_,
+    );
+}
+
 sub insights {
     my $self = shift;
 
@@ -220,62 +229,39 @@ sub _handle_4xx_status {
     my $uri      = shift;
     my $ip       = shift;
 
-    if ( $status == 404 ) {
-        WebService::MinFraud::Error::IPAddressNotFound->throw(
-            message    => "No record found for IP address $ip",
-            ip_address => $ip,
-        );
-    }
-
     my $content = $response->decoded_content;
 
-    my $body = {};
+    my $has_body = defined $content && length $content;
+    my $body = try {
+        $has_body
+            && $response->content_type =~ /json/
+            && $self->_json->decode($content)
+    };
 
-    if ( defined $content && length $content ) {
-        if ( $response->content_type =~ /json/ ) {
-            try {
-                $body = $self->_json->decode($content);
-                if ( !$body->{code} && !$body->{error} ) {
-                    WebService::MinFraud::Error::Generic->throw( message =>
-                            'Response contains JSON but it does not specify code or error keys'
-                    );
-                }
-                else {
-                    WebService::MinFraud::Error::WebService->throw(
-                        message => delete $body->{error},
-                        %{$body},
-                        http_status => $status,
-                        uri         => $uri,
-                    );
-                }
-            }
-            catch {
-                WebService::MinFraud::Error::HTTP->throw(
-                    message =>
-                        "Received a $status error for $uri with the following message: "
-                        . $_->message,
-                    http_status => $status,
-                    uri         => $uri,
-                );
-            };
-        }
-        else {
-            WebService::MinFraud::Error::HTTP->throw(
-                message =>
-                    "Received a $status error for $uri with the following body: $content",
+    if ($body) {
+        if ( $body->{code} || $body->{error} ) {
+            WebService::MinFraud::Error::WebService->throw(
+                message => delete $body->{error},
+                %{$body},
                 http_status => $status,
                 uri         => $uri,
             );
         }
+        else {
+            WebService::MinFraud::Error::Generic->throw( message =>
+                    'Response contains JSON but it does not specify code or error keys'
+            );
+        }
     }
     else {
         WebService::MinFraud::Error::HTTP->throw(
-            message     => "Received a $status error for $uri with no body",
+            message => $has_body
+            ? "Received a $status error for $uri with the following body: $content"
+            : "Received a $status error for $uri with no body",
             http_status => $status,
             uri         => $uri,
         );
     }
-
 }
 
 sub _handle_5xx_status {
@@ -299,7 +285,7 @@ sub _handle_non_200_status {
 
     WebService::MinFraud::Error::HTTP->throw(
         message =>
-            "Received an uncommon HTTP status ($status) for $uri that is neither 2xx, 4xx nor 5xx",
+            "Received an unexpected HTTP status ($status) for $uri that is neither 2xx, 4xx nor 5xx",
         http_status => $status,
         uri         => $uri,
     );
@@ -319,7 +305,7 @@ WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insight
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -342,8 +328,8 @@ version 0.002000
 
   my $request = { device => { ip_address => '24.24.24.24' } };
 
-  # Use the 'score' or 'insights' client methods, depending on the minFraud
-  # web service you are using.
+  # Use the 'score', 'insights', or 'factors' client methods, depending on
+  # the minFraud web service you are using.
 
   my $score = $client->score( $request );
   say $score->risk_score;
@@ -351,11 +337,14 @@ version 0.002000
   my $insights = $client->insights( $request );
   say $insights->shipping_address->is_high_risk;
 
+  my $factors = $client->factors( $request );
+  say $factors->subscores->ip_tenure;
+
 =head1 DESCRIPTION
 
-This class provides a client API for the MaxMind minFraud Score and Insights
-web services. The B<Insights> service returns more data about a transaction
-than the B<Score> service. See the
+This class provides a client API for the MaxMind minFraud Score, Insights, and
+Factors web services. The B<Insights> service returns more data about a
+transaction than the B<Score> service. See the
 L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
 for more details.
 
@@ -485,7 +474,7 @@ described below.
 
 =head1 REQUEST
 
-The request methods are passed a HashRef as the only argument. See the L</SYNOPSIS> and L<WebService::MinFraud::Example> for detailed usage examples.  Some important notes regarding values passed to the minFraud web service via the Perl API are described below.
+The request methods are passed a HashRef as the only argument. See the L</SYNOPSIS> and L<WebService::MinFraud::Example> for detailed usage examples. Some important notes regarding values passed to the minFraud web service via the Perl API are described below.
 
 =head2 device => ip_address
 
@@ -496,7 +485,7 @@ dotted-quad notation or the IPv6 hexadecimal-colon notation.
 
 All of the request methods require a device ip_address. See the
 L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
-for details on all the values that can be part of the request.  Portions of the
+for details on all the values that can be part of the request. Portions of the
 request hash with undefined and empty string values are automatically removed
 from the request.
 
@@ -510,6 +499,11 @@ L<WebService::MinFraud::Model::Score> object.
 This method calls the minFraud Insights web service. It returns a
 L<WebService::MinFraud::Model::Insights> object.
 
+=head2 factors
+
+This method calls the minFraud Factors web service. It returns a
+L<WebService::MinFraud::Model::Factors> object.
+
 =head1 User-Agent HEADER
 
 Requests by the minFraud Perl API will have a User-Agent header containing the
@@ -526,7 +520,7 @@ refer to the
 L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
 
 Prior to making the request to the web service, the request HashRef is passed
-to L<WebService::MinFraud::Validator> for checks.  If the request fails
+to L<WebService::MinFraud::Validator> for checks. If the request fails
 validation an exception is thrown, containing a string describing all of the
 validation errors.
 
@@ -574,7 +568,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
