@@ -5,7 +5,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 use parent 'Data::Rx::CommonType::EasyNew';
 
@@ -25,9 +25,8 @@ sub guts_from_arg {
                 contents => {
                     type     => '//rec',
                     required => {
-                        type =>
-                            '//str', # e.g. //int or //str.  Really we only
-                                     # want schemas that have a 'value' option
+                        type => '//str', # e.g. //int or //str. Really we only
+                             # want schemas that have a 'value' option
                         values => {
                             type     => '//arr',
                             contents => '//def',
@@ -54,7 +53,7 @@ sub guts_from_arg {
     my $schema = $rx->make_schema(
         {
             type => '//any',
-            of => [ map { { type => $type, value => $_ } } @values, ]
+            of   => [ map { { type => $type, value => $_ } } @values, ]
         }
     );
 
@@ -80,7 +79,7 @@ WebService::MinFraud::Data::Rx::Type::Enum - A type that defines an enumeration
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 AUTHOR
 
@@ -88,7 +87,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
