@@ -5,9 +5,9 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
-use Data::Validate::Domain qw( is_domain );
+use Data::Validate::Domain qw( is_hostname );
 
 use parent 'Data::Rx::CommonType::EasyNew';
 
@@ -18,8 +18,9 @@ with 'WebService::MinFraud::Role::Data::Rx::Type';
 sub assert_valid {
     my ( $self, $value ) = @_;
 
-    return 1
-        if is_domain($value);
+    # We use is_hostname rather than is_domain as Net::Domain::TLD cannot keep
+    # up with all of the new gTLDs
+    return 1 if is_hostname($value);
 
     $self->fail(
         {
@@ -31,7 +32,6 @@ sub assert_valid {
 }
 
 sub type_uri {
-    ## no critic(ValuesAndExpressions::ProhibitCommaSeparatedStatements)
     'tag:maxmind.com,MAXMIND:rx/hostname';
 }
 
@@ -49,7 +49,7 @@ WebService::MinFraud::Data::Rx::Type::Hostname - A type to check for a valid hos
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 AUTHOR
 
@@ -57,7 +57,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
