@@ -2,7 +2,7 @@ package WebService::MinFraud::Model::Insights;
 
 use Moo;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 use Types::Standard qw( HashRef InstanceOf );
 use WebService::MinFraud::Record::BillingAddress;
@@ -20,37 +20,14 @@ with 'WebService::MinFraud::Role::Model',
     'WebService::MinFraud::Role::HasLocales',
     'WebService::MinFraud::Role::HasCommonAttributes';
 
-{
-    my %attribute_to_class = (
-        billing_address  => 'WebService::MinFraud::Record::BillingAddress',
-        credit_card      => 'WebService::MinFraud::Record::CreditCard',
-        device           => 'WebService::MinFraud::Record::Device',
-        email            => 'WebService::MinFraud::Record::Email',
-        ip_address       => 'WebService::MinFraud::Record::IPAddress',
-        shipping_address => 'WebService::MinFraud::Record::ShippingAddress',
-    );
-
-    foreach my $attribute ( keys %attribute_to_class ) {
-        has $attribute => (
-            is => 'ro',
-            isa => InstanceOf [ $attribute_to_class{$attribute} ],
-        );
-    }
-    around BUILDARGS => sub {
-        my $orig  = shift;
-        my $class = shift;
-
-        my $args = $class->$orig(@_);
-
-        foreach my $attribute ( keys %attribute_to_class ) {
-            $args->{$attribute} //= {};
-            $args->{$attribute}
-                = $attribute_to_class{$attribute}->new( $args->{$attribute} );
-        }
-
-        return $args;
-    };
-}
+__PACKAGE__->_define_model_attributes(
+    billing_address  => 'BillingAddress',
+    credit_card      => 'CreditCard',
+    device           => 'Device',
+    email            => 'Email',
+    ip_address       => 'IPAddress',
+    shipping_address => 'ShippingAddress',
+);
 
 1;
 
@@ -66,7 +43,7 @@ WebService::MinFraud::Model::Insights - Model class for minFraud Insights
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -96,7 +73,7 @@ version 0.002000
 This class provides a model for the data returned by the minFraud Insights web
 service.
 
-The Insights model class includes more data than the Score model class.  See
+The Insights model class includes more data than the Score model class. See
 the L<API
 documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
 for more details.
@@ -128,14 +105,14 @@ request.
 
 =head2 id
 
-Returns a UUID that identifies the minFraud request.  Please use this UUID in
+Returns a UUID that identifies the minFraud request. Please use this UUID in
 bug reports or support requests to MaxMind so that we can easily identify a
 particular request.
 
 =head2 ip_address
 
 Returns a L<WebService::MinFraud::Record::IPAddress> object representing IP
-address data for the transaction.  This object has the following methods:
+address data for the transaction. This object has the following methods:
 
 =over 4
 
@@ -175,7 +152,7 @@ shipping data for the transaction.
 
 =head2 warnings
 
-Returns an ArrayRef of L<WebService::MinFraud::Record::Warning> objects.  It is
+Returns an ArrayRef of L<WebService::MinFraud::Record::Warning> objects. It is
 B<highly recommended that you check this array> for issues when integrating the
 web service.
 
@@ -198,7 +175,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
