@@ -2,12 +2,18 @@ package WebService::MinFraud::Model::Score;
 
 use Moo;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
+
+use WebService::MinFraud::Record::ScoreIPAddress;
 
 with 'WebService::MinFraud::Role::HasCommonAttributes',
     'WebService::MinFraud::Role::HasLocales',
     'WebService::MinFraud::Role::Model';
 
+__PACKAGE__->_define_model_attributes(
+    ip_address => 'ScoreIPAddress',
+);
+
 1;
 
 # ABSTRACT: Model class for minFraud: Score
@@ -22,7 +28,7 @@ WebService::MinFraud::Model::Score - Model class for minFraud: Score
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -58,18 +64,23 @@ The service credit counts are near realtime so they may not be exact.
 
 =head2 id
 
-Returns a UUID that identifies the minFraud request.  Please use this UUID in
+Returns a UUID that identifies the minFraud request. Please use this UUID in
 bug reports or support requests to MaxMind so that we can easily identify a
 particular request.
 
+=head2 ip_address
+
+Returns a L<WebService::MinFraud::Record::ScoreIPAddress> object representing
+IP address data for the transaction.
+
 =head2 risk_score
 
-Returns the risk score which is a number between 0.01 and 99.  A higher score
+Returns the risk score which is a number between 0.01 and 99. A higher score
 indicates a higher risk of fraud.
 
 =head2 warnings
 
-Returns an ArrayRef of L<WebService::MinFraud::Record::Warning> objects.  It is
+Returns an ArrayRef of L<WebService::MinFraud::Record::Warning> objects. It is
 B<highly recommended that you check this array> for issues when integrating the
 web service.
 
@@ -92,7 +103,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
