@@ -2,52 +2,52 @@ package WebService::MinFraud::Record::IPAddress;
 
 use Moo;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
+use B;
 use GeoIP2::Role::Model::Location;
 use GeoIP2::Role::Model::HasSubdivisions;
-use Types::Standard qw( ArrayRef InstanceOf Num);
+use Types::Standard qw( ArrayRef InstanceOf );
+use Sub::Quote qw( quote_sub );
 use WebService::MinFraud::Record::Location;
 use WebService::MinFraud::Record::Country;
-use WebService::MinFraud::Types qw(
-    MinFraudCountryCoercion
-    MinFraudLocationCoercion
-);
-with 'GeoIP2::Role::Model::Location', 'GeoIP2::Role::Model::HasSubdivisions';
 
-__PACKAGE__->_define_attributes_for_keys(
-    __PACKAGE__->_record_names_from_geo );
+with 'GeoIP2::Role::Model::Location', 'GeoIP2::Role::Model::HasSubdivisions',
+    'WebService::MinFraud::Role::Record::HasRisk';
 
-sub _record_names_from_geo {
-    qw(
-        city
-        continent
-        postal
-        registered_country
-        represented_country
-        traits
+__PACKAGE__->_define_attributes_for_keys( __PACKAGE__->_all_record_names() );
+
+for my $name ( 'Country', 'Location' ) {
+    my $attr = lc $name;
+
+    my $raw_attr = '_raw_' . $attr;
+    my $class    = "WebService::MinFraud::Record::$name";
+
+    has "+$attr" => (
+        is       => 'ro',
+        isa      => InstanceOf [$class],
+        init_arg => undef,
+        lazy     => 1,
+        default  => quote_sub(
+            ## no critic (ProhibitCallsToUnexportedSubs)
+            sprintf(
+                q{ $_[0]->_build_mf_record( %s, %s ) },
+                map { B::perlstring($_) } $class, $raw_attr
+            )
+        ),
+        predicate => 1,
     );
 }
 
-has country => (
-    is        => 'ro',
-    isa       => InstanceOf ['WebService::MinFraud::Record::Country'],
-    coerce    => MinFraudCountryCoercion,
-    predicate => 1,
-);
+sub _build_mf_record {
+    my $self   = shift;
+    my $class  = shift;
+    my $method = shift;
 
-has location => (
-    is        => 'ro',
-    isa       => InstanceOf ['WebService::MinFraud::Record::Location'],
-    coerce    => MinFraudLocationCoercion,
-    predicate => 1,
-);
+    my $raw = $self->$method;
 
-has risk => (
-    is        => 'ro',
-    isa       => Num,
-    predicate => 1,
-);
+    return $class->new( %{$raw}, locales => $self->locales() );
+}
 
 1;
 
@@ -63,7 +63,7 @@ WebService::MinFraud::Record::IPAddress - Contains data for the IPAddress record
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,7 @@ bases.
 =head2 risk
 
 Returns the risk associated with the IP address. The value ranges from 0.01 to
-99. A higher value indicates a higher risk.  The IP address risk is distinct
+99. A higher value indicates a higher risk. The IP address risk is distinct
 from the value returned by C<< risk_score >> methods of
 L<WebService::MinFraud::Model::Insights> and
 L<WebService::MinFraud::Model::Score> modules.
@@ -145,7 +145,7 @@ L<WebService::MinFraud::Model::Score> modules.
 =head2 subdivisions
 
 Returns an array of L<GeoIP2::Record::Subdivision> objects representing the
-country divisions for the IP address.  The number and type of subdivisions
+country divisions for the IP address. The number and type of subdivisions
 varies by country, but a subdivision is typically a state, province, county, or
 administrative region.
 
@@ -171,7 +171,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
