@@ -3,7 +3,7 @@ package WebService::MinFraud::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 use GeoIP2::Types qw(
     ArrayRef
@@ -40,8 +40,6 @@ our @EXPORT_OK = qw(
     LocalesArrayRef
     MaxMindID
     MaxMindLicenseKey
-    MinFraudCountryCoercion
-    MinFraudLocationCoercion
     NonNegativeInt
     Num
     Str
@@ -71,30 +69,6 @@ sub IssuerObjectCoercion () {
     );
 }
 
-sub MinFraudCountryCoercion () {
-    return quote_sub(
-        q{
-            defined $_[0]
-            && Scalar::Util::blessed($_[0])
-            && $_[0]->isa('WebService::MinFraud::Record::Country')
-            ? $_[0]
-            : WebService::MinFraud::Record::Country->new($_[0]);
-        }
-    );
-}
-
-sub MinFraudLocationCoercion () {
-    return quote_sub(
-        q{
-            defined $_[0]
-            && Scalar::Util::blessed($_[0])
-            && $_[0]->isa('WebService::MinFraud::Record::Location')
-            ? $_[0]
-            : WebService::MinFraud::Record::Location->new($_[0]);
-        }
-    );
-}
-
 1;
 
 # ABSTRACT: Custom types for the MaxMind minFraud service
@@ -109,7 +83,7 @@ WebService::MinFraud::Types - Custom types for the MaxMind minFraud service
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 AUTHOR
 
@@ -117,7 +91,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
