@@ -2,7 +2,7 @@ package WebService::MinFraud::Validator;
 
 use Moo;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.003000';
 
 use Data::Delete 0.05;
 use Data::Rx;
@@ -96,11 +96,11 @@ sub _build_request_schema_definition {
                     address_2  => '//str',
                     city       => '//str',
                     region     => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 1, 'max' => 4 },
                     },
                     country => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 2, 'max' => 2 },
                     },
                     postal             => '//str',
@@ -112,22 +112,22 @@ sub _build_request_schema_definition {
                 type     => '//rec',
                 optional => {
                     issuer_id_number => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 6, 'max' => 6 },
                     },
                     last_4_digits => => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 4, 'max' => 4 },
                     },
                     bank_name               => '//str',
                     bank_phone_country_code => '//int',
                     bank_phone_number       => '//str',
                     avs_result              => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 1, 'max' => 1 },
                     },
                     cvv_result => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 1, 'max' => 1 },
                     },
                 },
@@ -163,7 +163,7 @@ sub _build_request_schema_definition {
                 optional => {
                     amount   => '//num',
                     currency => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 3, 'max' => 3 },
                     },
                     discount_code    => '//str',
@@ -190,16 +190,18 @@ sub _build_request_schema_definition {
                                 'beanstream',
                                 'bluepay',
                                 'braintree',
+                                'ccnow',
                                 'chase_paymentech',
                                 'cielo',
                                 'collector',
                                 'compropago',
                                 'conekta',
                                 'cuentadigital',
+                                'dalpay',
                                 'dibs',
                                 'digital_river',
                                 'elavon',
-                                'epayeu',
+                                'epay',
                                 'eprocessing_network',
                                 'eway',
                                 'first_data',
@@ -215,22 +217,25 @@ sub _build_request_schema_definition {
                                 'mollie',
                                 'moneris_solutions',
                                 'nmi',
-                                'other',
                                 'openpaymx',
                                 'optimal_payments',
+                                'other',
                                 'payfast',
                                 'paygate',
                                 'payone',
                                 'paypal',
+                                'payplus',
                                 'paystation',
                                 'paytrace',
                                 'paytrail',
                                 'payture',
                                 'payu',
                                 'payulatam',
+                                'pinpayments',
                                 'princeton_payment_solutions',
                                 'psigate',
                                 'qiwi',
+                                'quickpay',
                                 'raberil',
                                 'rede',
                                 'redpagos',
@@ -244,6 +249,7 @@ sub _build_request_schema_definition {
                                 'telerecargas',
                                 'towah',
                                 'usa_epay',
+                                'verepay',
                                 'vindicia',
                                 'virtual_card_services',
                                 'vme',
@@ -276,17 +282,17 @@ sub _build_request_schema_definition {
                         },
                     },
                     region => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 1, 'max' => 4 },
                     },
                     country => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 2, 'max' => 2 },
                     },
                     postal             => '//str',
                     phone_number       => '//str',
                     phone_country_code => {
-                        type => '//str',
+                        type   => '//str',
                         length => { 'min' => 1, 'max' => 4 },
                     },
                 },
@@ -338,7 +344,7 @@ WebService::MinFraud::Validator - Validation for the minFraud requests
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -352,7 +358,7 @@ version 0.002000
 
 =head1 DESCRIPTION
 
-This module defines the request schema for the minFraud API.  In addition, it
+This module defines the request schema for the minFraud API. In addition, it
 provides a C<validate_request> method that is used to validate any request
 passed to the C<score> or C<insights> methods.
 
@@ -361,7 +367,7 @@ passed to the C<score> or C<insights> methods.
 =head2 validate_request
 
 This method takes a minFraud request as a HashRef and validates it against the
-minFraud request schema.  If the request HashRef fails validation, an exception
+minFraud request schema. If the request HashRef fails validation, an exception
 is thrown, which is a string containing all of the validation errors.
 
 =head1 AUTHOR
@@ -370,7 +376,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
